<no title> — django-bakery 0.3.2 documentation

### Navigation

- index
- next |
- previous |
- django-bakery 0.3.2 documentation »

#### Previous topic

Management commands

#### Next topic

Changelog

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- next |
- previous |
- django-bakery 0.3.2 documentation »

© Copyright 2014, Los Angeles Times Data Desk. Created using Sphinx 1.2.2.